@@ -58,7 +58,7 @@ struct MathButtonsPrivate
     GtkWidget *character_code_entry;
 };
 
-G_DEFINE_TYPE (MathButtons, math_buttons, GTK_TYPE_BOX);
+G_DEFINE_TYPE_WITH_PRIVATE (MathButtons, math_buttons, GTK_TYPE_BOX);
 
 #define UI_BASIC_FILE       UI_DIR "/buttons-basic.ui"
 #define UI_ADVANCED_FILE    UI_DIR "/buttons-advanced.ui"
@@ -584,6 +584,19 @@ load_mode(MathButtons *buttons, ButtonMode mode)
             gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), TRUE);
     }
 
+    /* put the icon name "process-stop" in the buttons
+       button1, button3, button5, button7, button9,
+       button11, button13, button15, button17, button19
+       taken from buttons-financial.ui */
+    for (i = 1; i < 20; i++) {
+        if (i % 2) {
+            widget = GET_WIDGET (builder, g_strdup_printf ("button%d",i));
+            if (GTK_IS_BUTTON(widget))
+                gtk_button_set_image (GTK_BUTTON (widget),
+                                      gtk_image_new_from_icon_name ("process-stop", GTK_ICON_SIZE_BUTTON));
+        }
+    }
+
     if (mode == PROGRAMMING) {
         GtkListStore *model;
         GtkTreeIter iter;
@@ -839,29 +852,14 @@ shift_cb(GtkWidget *widget, MathButtons *buttons)
     math_equation_shift(buttons->priv->equation, GPOINTER_TO_INT(g_object_get_data(G_OBJECT(widget), "shiftcount")));
 }
 
-
-static void
-button_menu_position_func(GtkMenu *menu, gint *x, gint *y,
-                          gboolean *push_in, gpointer user_data)
-{
-    GtkWidget *button = user_data;
-    GtkAllocation allocation;
-    GdkPoint loc;
-    gint border;
-  
-    gdk_window_get_origin(gtk_widget_get_window(button), &loc.x, &loc.y);
-    border = gtk_container_get_border_width(GTK_CONTAINER(button));
-    gtk_widget_get_allocation(button, &allocation);
-    *x = loc.x + allocation.x + border;
-    *y = loc.y + allocation.y + border;
-}
-
-
 static void
 popup_button_menu(GtkWidget *widget, GtkMenu *menu)
 {
-    gtk_menu_popup(menu, NULL, NULL,
-                   button_menu_position_func, widget, 1, gtk_get_current_event_time());
+    gtk_menu_popup_at_widget (menu,
+                              widget,
+                              GDK_GRAVITY_SOUTH_WEST,
+                              GDK_GRAVITY_NORTH_WEST,
+                              NULL);
 }
 
 
@@ -1333,8 +1331,6 @@ math_buttons_class_init(MathButtonsClass *klass)
     object_class->get_property = math_buttons_get_property;
     object_class->set_property = math_buttons_set_property;
 
-    g_type_class_add_private(klass, sizeof(MathButtonsPrivate));
-
     button_mode_type = g_enum_register_static("ButtonMode", button_mode_values);
 
     g_object_class_install_property(object_class,
@@ -1365,7 +1361,7 @@ math_buttons_class_init(MathButtonsClass *klass)
 static void
 math_buttons_init(MathButtons *buttons)
 {
-    buttons->priv = G_TYPE_INSTANCE_GET_PRIVATE(buttons, math_buttons_get_type(), MathButtonsPrivate);
+    buttons->priv = math_buttons_get_instance_private (buttons);
     gtk_box_set_spacing(GTK_BOX(buttons), 6);
     gtk_orientable_set_orientation (GTK_ORIENTABLE (buttons),
                                     GTK_ORIENTATION_VERTICAL);
